@@ -415,7 +415,7 @@ def ParseOSXSysConfig():
     "Retrieves the current Mac OS X resolver settings using the scutil(8) command."
     import os, re
     scutil = os.popen('/usr/sbin/scutil --dns', 'r')
-    res_re = re.compile('^\s+nameserver[]0-9[]*\s*\:\s*(\S+)$')
+    res_re = re.compile(r'^\s+nameserver[]0-9[]*\s*\:\s*(\S+)$')
     sets = [ ]
     currentset = None
     while True:
