@@ -36,12 +36,12 @@ class TestBase(unittest.TestCase):
         self.assertTrue(a_response.answers)
         # is the result vaguely ipv4 like?
         self.assertEqual(a_response.answers[0]['data'].count('.'), 3)
-        self.assertEqual(a_response.answers[0]['data'],'93.184.216.34')
+        self.assertEqual(a_response.answers[0]['data'],'93.184.215.14')
 
         # Default result type for .qry object is an ipaddress object
         ad_response = dnsobj.qry(qtype='A', timeout=1)
         self.assertTrue(ad_response.answers)
-        self.assertEqual(ad_response.answers[0]['data'],ipaddress.IPv4Address('93.184.216.34'))
+        self.assertEqual(ad_response.answers[0]['data'],ipaddress.IPv4Address('93.184.215.14'))
 
         ab_response = dnsobj.qry(qtype='A', resulttype='binary', timeout=1)
         self.assertTrue(ab_response.answers)
@@ -49,11 +49,11 @@ class TestBase(unittest.TestCase):
         self.assertEqual(len(ab_response.answers[0]['data']), 4)
         for b in ab_response.answers[0]['data']:
             assertIsByte(b)
-        self.assertEqual(ab_response.answers[0]['data'],b']\xb8\xd8\"')
+        self.assertEqual(ab_response.answers[0]['data'],b']\xb8\xd7\x0e')
 
         ai_response = dnsobj.qry(qtype='A', resulttype='integer', timeout=1)
         self.assertTrue(ai_response.answers)
-        self.assertEqual(ai_response.answers[0]['data'],1572395042)
+        self.assertEqual(ai_response.answers[0]['data'],1572394766)
 
 
     def testDnsRequestAAAA(self):
@@ -63,12 +63,12 @@ class TestBase(unittest.TestCase):
         self.assertTrue(aaaa_response.answers)
         # does the result look like an ipv6 address?
         self.assertTrue(':' in aaaa_response.answers[0]['data'])
-        self.assertEqual(aaaa_response.answers[0]['data'],'2606:2800:220:1:248:1893:25c8:1946')
+        self.assertEqual(aaaa_response.answers[0]['data'],'2606:2800:21f:cb07:6820:80da:af6b:8b2c')
 
         # default is returning ipaddress object
         aaaad_response = dnsobj.qry(qtype='AAAA', timeout=1)
         self.assertTrue(aaaad_response.answers)
-        self.assertEqual(aaaad_response.answers[0]['data'],ipaddress.IPv6Address('2606:2800:220:1:248:1893:25c8:1946'))
+        self.assertEqual(aaaad_response.answers[0]['data'],ipaddress.IPv6Address('2606:2800:21f:cb07:6820:80da:af6b:8b2c'))
         
         aaaab_response = dnsobj.qry(qtype='AAAA', resulttype='binary', timeout=1)
         self.assertTrue(aaaab_response.answers)
@@ -76,11 +76,11 @@ class TestBase(unittest.TestCase):
         self.assertEqual(len(aaaab_response.answers[0]['data']) , 16)
         for b in aaaab_response.answers[0]['data']:
             assertIsByte(b)
-        self.assertEqual(aaaab_response.answers[0]['data'],b'&\x06(\x00\x02 \x00\x01\x02H\x18\x93%\xc8\x19F')
+        self.assertEqual(aaaab_response.answers[0]['data'],b'&\x06(\x00\x02\x1f\xcb\x07h \x80\xda\xafk\x8b,')
         # IPv6 decimal
         aaaai_response = dnsobj.qry(qtype='AAAA', resulttype='integer', timeout=1)
         self.assertTrue(aaaai_response.answers)
-        self.assertEqual(aaaai_response.answers[0]['data'], 50542628918019813867414319910101719366)
+        self.assertEqual(aaaai_response.answers[0]['data'], 50542628918019563700009922510424083244)
 
     def testDnsRequestEmptyMX(self):
         dnsobj = DNS.DnsRequest('mail.kitterman.org')
@@ -170,7 +170,7 @@ class TestBase(unittest.TestCase):
         self.assertTrue(ad_response.answers)
         # is the result vaguely ipv4 like?
         self.assertEqual(ad_response.answers[0]['data'].count('.'), 3)
-        self.assertEqual(ad_response.answers[0]['data'],'93.184.216.34')
+        self.assertEqual(ad_response.answers[0]['data'],'93.184.215.14')
 
     def testDnsRequestAAAAD(self):
         dnsob = DNS.DnsRequest('example.org')
@@ -182,7 +182,7 @@ class TestBase(unittest.TestCase):
         self.assertEqual(len(aaaad_response.answers[0]['data']) , 16)
         for b in aaaad_response.answers[0]['data']:
             assertIsByte(b)
-        self.assertEqual(aaaad_response.answers[0]['data'],b'&\x06(\x00\x02 \x00\x01\x02H\x18\x93%\xc8\x19F')
+        self.assertEqual(aaaad_response.answers[0]['data'],b'&\x06(\x00\x02\x1f\xcb\x07h \x80\xda\xafk\x8b,')
         
     def testDnsRequestEmptyMXD(self):
         dnsob = DNS.DnsRequest('mail.kitterman.org')
